__author__ = "Daniel Peña Iglesias"
__copyright__ = "Copyright (C) 2023 Daniel Peña Iglesias"
__credits__ = ["Daniel Peña Iglesias"]
__license__ = "MIT"

from asynciodize.asynciodize import asynciodize